@@ -7,19 +7,17 @@ package Date::Language::French;
 use Date::Language ();
 use vars qw(@ISA @DoW @DoWs @MoY @MoYs @AMPM @Dsuf %MoY %DoW $VERSION);
 @ISA = qw(Date::Language);
-$VERSION = "1.01";
+$VERSION = "1.04";
 
-@DoW = qw(dimanche lundi mardi mercredi vendredi samedi);
+@DoW = qw(dimanche lundi mardi mercredi jeudi vendredi samedi);
 @MoY = qw(janvier fvrier mars avril mai juin 
           juillet aot septembre octobre novembre dcembre);
 @DoWs = map { substr($_,0,3) } @DoW;
-@MoYs = map { substr($_,0,4) } @MoY; # 4 insteed of 3 'cause [juin] [juil]let
+@MoYs = map { substr($_,0,3) } @MoY;
+$MoYs[6] = 'jul';
 @AMPM = qw(AM PM);
 
-@Dsuf = (qw(er e e e e e e e e e)) x 3;
-# Not need..
-# @Dsuf[11,12,13] = qw(th th th);
-# @Dsuf[30,31] = qw(th st);
+@Dsuf = ((qw(er e e e e e e e e e)) x 3, 'er')
 
 @MoY{@MoY}  = (0 .. scalar(@MoY));
 @MoY{@MoYs} = (0 .. scalar(@MoYs));
